@@ -2,6 +2,6 @@ __author__ = 'Lijun Yu'
 
 from .runtime import Options
 from .stage import ReorderStage, Stage
-from .system import Job, System
+from .system import Job, Result, System
 from .task import Task
 from .utils import get_logger, progressbar
